(function (Drupal) {
  Drupal.behaviors.BookableCalendarOneClickBooking = {
    attach: function (context, settings) {
      if (context !== document) {
        return;
      }
      const bookButtons = context.querySelectorAll('.availability__link:not(.is-disabled)');
      bookButtons.forEach(element => {
        element.addEventListener('click', function(e) {
          e.preventDefault();
          let button = this;
          button.classList.add('loading', 'is-disabled');
          let openingId = button.dataset.openingInstance;
          let slotsAvailable = parseInt(button.dataset.slotsAvailable);
          if (slotsAvailable !== 0) {
            let myHeaders = new Headers();
            myHeaders.append('Content-Type', 'application/json');

            var raw = JSON.stringify({
              'contact_info': {
                'email': drupalSettings.one_click_booking.email,
                'party_size': 1,
                'uid': drupalSettings.one_click_booking.uid
              }
            });

            let requestOptions = {
              method: 'POST',
              headers: myHeaders,
              body: raw,
              redirect: 'follow'
            };

            fetch('/bookable-calendar/' + openingId + '/book', requestOptions)
              .then(response => response.text())
              .then(result => {
                let results = JSON.parse(result);
                if (results.status === 'success') {
                  button.innerText = drupalSettings.one_click_booking.booked_text;
                  button.classList.remove('loading');
                  slotsAvailable--;
                  button.dataset.slotsAvailable = slotsAvailable;

                  if (button.parentElement.querySelector('.availability__seats-available')) {
                    button.parentElement.querySelector('.availability__seats-available').outerText = slotsAvailable;
                  }
                }
              })
              .catch(error => {
                console.log(error);
              });
          }
        });
      });

    }
  };
})(Drupal);
